File: README.md
Introduction
Quickemu is a wrapper for the excellent QEMU that
automatically "does the right thing" when creating virtual machines. No
requirement for exhaustive configuration options. You decide what operating
system you want to run and Quickemu takes care of the rest ๐ค
quickgetautomatically downloads the upstream OS and creates the configuration ๐quickemuenumerates your hardware and launches the virtual machine with the optimum configuration best suited to your computer โก๏ธ
The original objective of the project was to enable quick testing of Linux
distributions
where the virtual machines and their configuration can be stored anywhere (such
as external USB storage or your home directory) and no elevated permissions are
required to run the virtual machines.
Today, Quickemu includes comprehensive support for macOS,
Windows, most of the BSDs, novel non-Linux operating systems such as FreeDOS, Haiku, KolibriOS, OpenIndiana, ReactOS, and more.
Features
- Host support for Linux and macOS
- macOS Sequoia, Sonoma, Ventura, Monterey, Big Sur, Catalina & Mojave
- Windows 10 and 11 including TPM 2.0
- Windows Server 2022 2019 2016
- ARM64 guest support for running aarch64 VMs (native on ARM hosts, emulated on x86_64)
- Ubuntu and all the official Ubuntu
flavours - Nearly 1000 operating system editions are supported!
- Full SPICE support including host/guest clipboard sharing
- VirtIO-webdavd file sharing for Linux and Windows guests
- VirtIO-9p file sharing for Linux and macOS guests
- QEMU Guest Agent
support; provides access
to a system-level agent via standard QMP commands - Samba file sharing for Linux, macOS and Windows guests (if
smbd
is installed on the host) - VirGL acceleration
- USB device pass-through
- Smartcard pass-through
- Automatic SSH port forwarding to guests
- Network port forwarding
- Full duplex audio
- Braille support
- EFI (with or without SecureBoot) and Legacy BIOS boot
As featured on [Linux Matters](https://linuxmatters.sh) podcast!
The presenters of Linux Matters ๐ง๐๏ธ are the creators of each of the principal Quickemu projects. We discussed Quickemu's 2024 reboot in Episode 30 - Quickemu Rising From the Bashes.
Quick start
Once Quickemu is installed, there are two simple steps to create and run a virtual machine:
quickgetautomatically downloads the ISO image for the operating system you want to run and creates a configuration file for the virtual machine.
quickget nixos unstable minimalquickemustarts the virtual machine using the configuration file created byquickget.
quickemu --vm nixos-unstable-minimal.confExecute quickget (with no arguments) to see a list of all the supported operating systems.
Demo
Documentation
The wiki describes how to get up and running with Quickemu and also covers more advanced configuration and usage.
- Installation ๐พ
- Create Linux virtual machines ๐ง
- Create macOS virtual machines ๐
- Create Windows virtual machines ๐ช
- Advanced quickemu configuration ๐ง
- Advanced quickget features ๐ค
- Alternative frontends ๐งโ๐ป
- References ๐๏ธ
File: docs/quickemu.1.md
author: Martin Wimpress date: February 2, 2026 footer: quickemu header: Quickemu User Manual section: 1 title: QUICKEMU
NAME
quickemu - A quick VM builder and manager
SYNOPSIS
quickemu [OPTION]...
DESCRIPTION
quickemu will create and run highly optimised desktop virtual
machines for Linux, macOS and Windows
OPTIONS
--vm
: vm configuration file
You can also pass optional parameters
--access
: Enable remote spice access support. 'local' (default), 'remote',
'clientipaddress'
--braille
: Enable braille support. Requires SDL.
--delete-disk
: Delete the disk image and EFI variables
--delete-vm
: Delete the entire VM and its configuration
--display
: Select display backend. 'gtk' (default), 'sdl', 'cocoa', 'none',
'spice' or 'spice-app'
--fullscreen
: Starts VM in full screen mode (Ctl+Alt+f to exit)
--ignore-msrs-always
: Configure KVM to always ignore unhandled machine-specific registers
--kill
: Kill the VM process if it is running
--offline
: Override all network settings and start the VM offline
--shortcut
: Create a desktop shortcut
--snapshot apply <tag>
: Apply/restore a snapshot.
--snapshot create <tag>
: Create a snapshot.
--snapshot delete <tag>
: Delete a snapshot.
--snapshot info
: Show disk/snapshot info.
--status-quo
: Do not commit any changes to disk/snapshot.
--viewer <viewer>
: Choose an alternative viewer. @Options: 'spicy' (default),
'remote-viewer', 'none'
--width <width>
: Set VM screen width; requires '--height'
--height <height>
: Set VM screen height; requires '--width'
**--ssh-port **
: Set SSH port manually
**--spice-port **
: Set SPICE port manually
**--public-dir **
: Expose share directory. @Options: '' (default: xdg-user-dir
PUBLICSHARE), '
--monitor <type>
: Set monitor connection type. @Options: 'socket' (default), 'telnet',
'none'
**--monitor-telnet-host **
: Set telnet host for monitor. (default: 'localhost')
**--monitor-telnet-port **
: Set telnet port for monitor. (default: '4440')
--monitor-cmd <cmd>
: Send command to monitor if available. (Example: system_powerdown)
--serial <type>
: Set serial connection type. @Options: 'socket' (default), 'telnet',
'none'
**--serial-telnet-host **
: Set telnet host for serial. (default: 'localhost')
**--serial-telnet-port **
: Set telnet port for serial. (default: '6660')
--keyboard <type>
: Set keyboard. @Options: 'usb' (default), 'ps2', 'virtio'
--keyboard_layout <layout>
: Set keyboard layout: 'en-us' (default)
--mouse <type>
: Set mouse. @Options: 'tablet' (default), 'ps2', 'usb', 'virtio'
--usb-controller <type>
: Set usb-controller. @Options: 'ehci' (default), 'xhci', 'none'
--sound-card <type>
: Set sound card. @Options: 'intel-hda' (default), 'ac97', 'es1370',
'sb16', 'none'
--extra_args <arguments>
: Pass additional arguments to qemu
--version
: Print version
EXAMPLES
quickemu --vm ubuntu-mate-22.04.conf
: Launches the VM specified in the file ubuntu-mate-22.04.conf
Introduction
Quickemu is a wrapper for the excellent
QEMU that automatically "does the right
thing" when creating virtual machines. No requirement for exhaustive
configuration options. You decide what operating system you want to run
and Quickemu takes care of the rest ๐ค
quickgetautomatically downloads the upstream OS and creates the
configuration ๐quickemuenumerates your hardware and launches the virtual machine
with the optimum configuration best suited to your computer โก๏ธ
The original objective of the project was to enable quick testing of
Linux
distributions
where the virtual machines and their configuration can be stored
anywhere (such as external USB storage or your home directory) and no
elevated permissions are required to run the virtual machines.
Today, Quickemu includes comprehensive support for
macOS,
Windows,
most of the BSDs, novel non-Linux operating systems such as FreeDOS,
Haiku, KolibriOS, OpenIndiana, ReactOS, and more.
Features
- Host support for Linux and macOS
- macOS Sequoia, Sonoma, Ventura, Monterey, Big Sur, Catalina &
Mojave - Windows 10 and 11 including TPM 2.0
- Windows Server 2022 2019 2016
- ARM64 guest support for running aarch64 VMs (native on ARM hosts,
emulated on x86_64) - Ubuntu and all the official Ubuntu
flavours - Nearly 1000 operating system editions are supported!
- Full SPICE support including host/guest clipboard sharing
- VirtIO-webdavd file sharing for Linux and Windows guests
- VirtIO-9p file sharing for Linux and macOS guests
- QEMU Guest Agent support;
provides access to a system-level agent via standard QMP commands - Samba file sharing for Linux, macOS and Windows guests (if
smbdis
installed on the host) - VirGL acceleration
- USB device pass-through
- Smartcard pass-through
- Automatic SSH port forwarding to guests
- Network port forwarding
- Full duplex audio
- Braille support
- EFI (with or without SecureBoot) and Legacy BIOS boot
As featured on [Linux Matters](https://linuxmatters.sh) podcast!
The presenters of Linux Matters ๐ง๐๏ธ are the creators of each of the
principal Quickemu projects. We discussed Quickemu's 2024 reboot in
Episode 30 - Quickemu Rising From the
Bashes.
When installing from source, you will need to install the following
requirements manually:
- QEMU (6.0.0 or newer) with GTK, SDL,
SPICE & VirtFS support - bash (4.0 or newer)
- Coreutils
- curl
- EDK II
- gawk
- grep
- glxinfo
- jq
- LSB
- pciutils
- procps
- python3
- mkisofs
- usbutils
- util-linux; including
uuidgen - sed
- socat
- spicy
- swtpm
- xdg-user-dirs
- xrandr
- zsync
- unzip
For Ubuntu, Debian, Fedora, Arch and NixOS hosts the native packaging or
ppa,
AUR or
nix
packaging will take care of the dependencies. For other host
distributions or operating systems it will be necessary to install the
above requirements or their equivalents.
These examples may save a little typing:
Install requirements on Debian hosts
These should be handled by dependencies in Trixie and later. For earlier
versions (and their derivatives):
sudo apt-get install bash coreutils curl genisoimage grep jq mesa-utils ovmf pciutils procps python3 qemu sed socat spice-client-gtk swtpm-tools unzip usbutils util-linux xdg-user-dirs xrandr zsyncInstall requirements on Fedora hosts
These are handled natively for Fedora 41 on. For earlier versions:
sudo dnf install bash coreutils curl edk2-tools genisoimage grep jq mesa-demos pciutils procps python3 qemu sed socat spice-gtk-tools swtpm unzip usbutils util-linux uuidgen-runtime xdg-user-dirs xrandr zsyncInstall requirements on Gentoo
Please note that you may have to use sys-firmware/edk2-ovmf instead ofsys-firmware/edk2-ovmf-bin - depending on how your system is
configured.
sudo emerge --ask --noreplace app-emulation/qemu \
app-shells/bash \
sys-apps/coreutils \
net-misc/curl \
sys-firmware/edk2-ovmf-bin \
sys-apps/gawk \
sys-apps/grep \
x11-apps/mesa-progs \
app-misc/jq \
sys-apps/pciutils \
sys-process/procps \
app-cdr/cdrtools \
sys-apps/usbutils \
sys-apps/util-linux \
sys-apps/sed \
net-misc/socat \
app-emulation/spice \
app-crypt/swtpm \
x11-misc/xdg-user-dirs \
x11-apps/xrandr \
net-misc/zsync \
app-arch/unzipInstall requirements on macOS hosts
Install the Quickemu requirements using brew:
brew install bash cdrtools coreutils jq python3 qemu usbutils samba socat swtpm zsyncNow clone the project:
git clone https://github.com/quickemu-project/quickemu
cd quickemu[Alternative Frontends](https://github.com/quickemu-project/quickemu/wiki/07-Alternative-frontends)
Quickgui
While quickemu and quickget are designed for the terminal, a
graphical user interface is also available:
- Quickgui by Mark
Johnson and Yannick
Mauray.
To install Quickgui on Ubuntu:
sudo add-apt-repository ppa:yannick-mauray/quickgui
sudo apt update
sudo apt install quickguiMany thanks to Luke Wesley-Holley and
Philipp Kiemle for creating the
Quickemu icons ๐จ
Creating Linux guests ๐ง
Ubuntu
quickget will automatically download an Ubuntu release and create the
virtual machine configuration.
quickget ubuntu 22.04
quickemu --vm ubuntu-22.04.conf- Complete the installation as normal.
- Post-install:
- Install the SPICE agent (
spice-vdagent) in the guest to enable
copy/paste and USB redirectionsudo apt install spice-vdagent
- Install the SPICE WebDAV agent (
spice-webdavd) in the guest to
enable file sharing.sudo apt install spice-webdavd
- Install the SPICE agent (
Ubuntu daily-live images
quickget can also download/refresh daily-live images via zsync for
Ubuntu developers and testers.
quickget ubuntu daily-live
quickemu --vm ubuntu-daily-live.confYou can run quickget ubuntu daily-live to refresh your daily
development image as often as you like, it will even automatically
switch to a new series.
Ubuntu Flavours
All the official Ubuntu flavours are supported, just replace ubuntu
with your preferred flavour.
The project
wiki
may have further information.
edubuntu(Edubuntu)kubuntu(Kubuntu)lubuntu(Lubuntu)ubuntu-budgie(Ubuntu Budgie)ubuntucinnamon(Ubuntu Cinnamon)ubuntukylin(Ubuntu Kylin)ubuntu-mate(Ubuntu MATE)ubuntu-server(Ubuntu Server)ubuntustudio(Ubuntu Studio)ubuntu(Ubuntu)ubuntu-unity(Ubuntu Unity)xubuntu(Xubuntu)
You can also use quickget with advanced options :
--arch <arch> : Set architecture (arm64, aarch64, amd64, x86_64)
--download <os> <release> [edition] : Download image; no VM configuration
--create-config <os> [path/url] [flags] : Create VM config for an OS image
--open-homepage <os> : Open homepage for the OS
--show [os] : Show OS information
--version : Show version
--help : Show this help message
------------------------------------ Flags -------------------------------------
--create-config:
--disable-unattended : Force quickget not to set up an unattended installation
-------------------------- For testing & development ---------------------------
--url [os] [release] [edition] : Show image URL(s)
--check [os] [release] [edition] : Check image URL(s)
--check-all-arch [os] [release] [edition] : Check downloads for all architectures (amd64 and arm64)
--list : List all supported systems
--list-csv : List everything in csv format
--list-json : List everything in json formatHere are some typical uses
# show an OS ISO download URL for {os} {release} [edition]
quickget --url fedora 38 Silverblue
# test if an OS ISO is available for {os} {release} [edition]
quickget --check nixos unstable plasma5
# open an OS distribution homepage in a browser
quickget --open-homepage ubuntu-mate
# Only download image file into current directory, without creating VM
quickget --download elementary 7.1The --url, --check, and --download options are fully functional
for all operating systems, including Windows and macOS.
Further information is available from the project
wiki
Other Operating Systems
quickget also supports:
alma(AlmaLinux)alpine(Alpine Linux)android(Android x86)antix(Antix)archcraft(Archcraft)archlinux(Arch Linux)artixlinux(Artix Linux)azurelinux(Azure Linux)batocera(Batocera)bazzite(Bazzite)biglinux(BigLinux)blendos(BlendOS)bodhi(Bodhi)bunsenlabs(BunsenLabs)cachyos(CachyOS)centos-stream(CentOS Stream)chimeralinux(Chimera Linux)crunchbang++(Crunchbangplusplus)debian(Debian)deepin(Deepin)devuan(Devuan)dragonflybsd(DragonFlyBSD)easyos(EasyOS)elementary(elementary OS)endeavouros(EndeavourOS)endless(Endless OS)fedora(Fedora)freebsd(FreeBSD)freedos(FreeDOS)garuda(Garuda Linux)gentoo(Gentoo)ghostbsd(GhostBSD)gnomeos(GNOME OS)guix(Guix)haiku(Haiku)kali(Kali)kdeneon(KDE Neon)kolibrios(KolibriOS)linuxlite(Linux Lite)linuxmint(Linux Mint)lmde(Linux Mint Debian Edition)maboxlinux(Mabox Linux)mageia(Mageia)manjaro(Manjaro)mxlinux(MX Linux)netboot(netboot.xyz)netbsd(NetBSD)nitrux(Nitrux)nixos(NixOS)nwg-shell(nwg-shell)openbsd(OpenBSD)openindiana(OpenIndiana)opensuse(openSUSE)oraclelinux(Oracle Linux)parrotsec(Parrot Security)pclinuxos(PCLinuxOS)peppermint(PeppermintOS)popos(Pop!_OS)porteus(Porteus)primtux(PrimTux)proxmox-ve(Proxmox VE)pureos(PureOS)reactos(ReactOS)rebornos(RebornOS)rockylinux(Rocky Linux)siduction(Siduction)slackware(Slackware)slax(Slax)slint(Slint)slitaz(SliTaz)solus(Solus)sparkylinux(SparkyLinux)spirallinux(SpiralLinux)tails(Tails)tinycore(Tiny Core Linux)trisquel(Trisquel)tuxedo-os(Tuxedo OS)vanillaos(Vanilla OS)void(Void Linux)zorin(Zorin OS)
[Custom Linux guests](https://github.com/quickemu-project/quickemu/wiki/02-Create-Linux-virtual-machines#manually-create-linux-guests)
Or you can download a Linux image and manually create a VM
configuration.
- Download a .iso image of a Linux distribution
- Create a VM configuration file; for example
debian-bullseye.conf
guest_os="linux"
disk_img="debian-bullseye/disk.qcow2"
iso="debian-bullseye/firmware-11.0.0-amd64-DVD-1.iso"- Use
quickemuto start the virtual machine:
quickemu --vm debian-bullseye.conf- Complete the installation as normal.
- Post-install:
- Install the SPICE agent (
spice-vdagent) in the guest to enable
copy/paste and USB redirection. - Install the SPICE WebDAV agent (
spice-webdavd) in the guest to
enable file sharing.
- Install the SPICE agent (
Supporting old Linux distros
If you want to run an old Linux , from 2016 or earlier, change theguest_os to linux_old. This will enable the vmware-svga graphics
driver which is better supported on older distros.
[Creating macOS Guests](https://github.com/quickemu-project/quickemu/wiki/03-Create-macOS-virtual-machines#automatically-create-macos-guests) ๐
Installing macOS in a VM can be a bit finicky, if you encounter
problems, check the
Discussions
for solutions or ask for help there ๐
quickget automatically downloads a macOS recovery image and creates a
virtual machine configuration.
Note: Some VPN users may need to turn off their
VPN
in order to download a recovery image. Some other users may find using
a
VPN
necessary in order to download a recovery image.
quickget macos big-sur
quickemu --vm macos-big-sur.confmacOS mojave, catalina, big-sur, monterey, ventura andsonoma are supported.
- Use cursor keys and enter key to select the macOS Base System
- From macOS Utilities
- Click Disk Utility and Continue
- Select
QEMU HARDDISK Media(~103.08GB) from the list (on Big Sur
and above useApple Inc. VirtIO Block Device) and click
Erase. - Enter a
Name:for the disk - If you are installing macOS Mojave or later (Catalina, Big Sur,
Monterey, Ventura and Sonoma), choose any of the APFS options as
the filesystem. MacOS Extended may not work.
- Select
- Click Erase.
- Click Done.
- Close Disk Utility
- Click Disk Utility and Continue
- From macOS Utilities
- Click Reinstall macOS and Continue
- Complete the installation as you normally would.
- On the first reboot use cursor keys and enter key to select macOS
Installer - On the subsequent reboots use cursor keys and enter key to select
the disk you named
- On the first reboot use cursor keys and enter key to select macOS
- Once you have finished installing macOS you will be presented with an
the out-of-the-box first-start wizard to configure various options and
set up your username and password - OPTIONAL: After you have concluded the out-of-the-box wizard, you may
want to enable the TRIM feature that the computer industry created for
SSD disks. This feature in our macOS installation will allow QuickEmu
to compact (shrink) your macOS disk image whenever you delete files
inside the Virtual Machine. Without this step your macOS disk image
will only ever get larger and will not shrink even when you delete
lots of data inside macOS.- To enable TRIM, open the Terminal application and type the following
command followed by pressing enter to tell macos to use
the TRIM command on the hard disk when files are deleted:
- To enable TRIM, open the Terminal application and type the following
sudo trimforce enableYou will be prompted to enter your account's password to gain the
privilege needed. Once you've entered your password and pressed
enter the command will request confirmation in the form of
two questions that require you to type y (for a "yes"
response) followed by enter to confirm.
If you press enter without first typing y the
system will consider that a negative response as though you said "no":
IMPORTANT NOTICE: This tool force-enables TRIM for all relevant attached devices, even though such devices may not have been validated for data integrity while using TRIM. Use of this tool to enable TRIM may result in unintended data loss or data corruption. It should not be used in a commercial operating environment or with important data. Before using this tool, you should back up all of your data and regularly back up data while TRIM is enabled. This tool is provided on an "as is" basis. APPLE MAKES NO WARRANTIES, EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION THE IMPLIED WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE, REGARDING THIS TOOL OR ITS USE ALONE OR IN COMBINATION WITH YOUR DEVICES, SYSTEMS, OR SERVICES. BY USING THIS TOOL TO ENABLE TRIM, YOU AGREE THAT, TO THE EXTENT PERMITTED BY APPLICABLE LAW, USE OF THE TOOL IS AT YOUR SOLE RISK AND THAT THE ENTIRE RISK AS TO SATISFACTORY QUALITY, PERFORMANCE, ACCURACY AND EFFORT IS WITH YOU.
Are you sure you with to proceed (y/N)?And a second confirmation once you've confirmed the previous one:
Your system will immediately reboot when this is complete.
Is this OK (y/N)?As the last message states, your system will automatically reboot as
soon as the command completes.
The default macOS configuration looks like this:
guest_os="macos"
img="macos-big-sur/RecoveryImage.img"
disk_img="macos-big-sur/disk.qcow2"
macos_release="big-sur"guest_os="macos"instructs Quickemu to optimise for macOS.macos_release="big-sur"instructs Quickemu to optimise for a
particular macOS release.- For example VirtIO Network and Memory Ballooning are available in
Big Sur and newer, but not previous releases. - And VirtIO Block Media (disks) are supported/stable in Catalina and
newer.
- For example VirtIO Network and Memory Ballooning are available in
macOS compatibility
There are some considerations when running macOS via Quickemu.
- Supported macOS releases:
- Mojave
- Catalina
- Big Sur
- Monterey
- Ventura
- Sonoma
quickemuwill automatically download the required
OpenCore bootloader and
OVMF firmware from OSX-KVM.- Optimised by default, but no GPU acceleration is available.
- Host CPU vendor is detected and guest CPU is optimised accordingly.
- VirtIO Block
Media is
used for the system disk where supported. - VirtIO
usb-tabletis used for
the mouse. - VirtIO Network (
virtio-net) is supported and enabled on macOS Big
Sur and newer, but earlier releases usevmxnet3. - VirtIO Memory Ballooning is supported and enabled on macOS Big Sur
and newer but disabled for other support macOS releases.
- USB host and SPICE pass-through is:
- UHCI (USB 2.0) on macOS Catalina and earlier.
- XHCI (USB 3.0) on macOS Big Sur and newer.
- Display resolution can be changed via
quickemuusing--widthand--heightcommand line arguments. - Full Duplex audio requires VoodooHDA
OC or pass-through a USB
audio-device to the macOS guest VM.- NOTE! Gatekeeper and
System Integrity Protection
(SIP)
need to be disabled to install VoodooHDA OC
- NOTE! Gatekeeper and
- File sharing between guest and host is available via
virtio-9p and SPICE
webdavd. - Copy/paste via SPICE agent is not available on macOS.
macOS App Store
If you see "Your device or computer could not be verified" when you
try to login to the App Store, make sure that your wired ethernet device
is en0. Use ifconfig in a terminal to verify this.
If the wired ethernet device is not en0, then then go to System
Preferences -> Network, delete all the network devices and apply the
changes. Next, open a terminal and run the following:
sudo rm /Library/Preferences/SystemConfiguration/NetworkInterfaces.plistNow reboot, and the App Store should work.
There may be further advice and information about macOS guests in the
project
wiki.
[Creating Windows guests](https://github.com/quickemu-project/quickemu/wiki/04-Create-Windows-virtual-machines) ๐ช
quickget can download Windows
10 and
Windows 11
automatically and create an optimised virtual machine configuration.
This configuration also includes the VirtIO drivers for
Windows.
Windows 8.1 is also supported but doesn't feature any automated
installation or driver optimisation.
quickget can also download Windows 10
LTSC
and Windows Server
2012-r2,
2016,
2019,
and
2022.
No automated installation is supported for these releases.
quickget windows 11
quickemu --vm windows-11.conf- Complete the installation as you normally would.
- All relevant drivers and services should be installed automatically.
- A local administrator user account is automatically created, with
these credentials:- Username:
Quickemu - Password:
quickemu
- Username:
Further information is available from the project
wiki
Configuration
Here are the usage instructions:
/* Detailed source-code truncated for AI context efficiency. */Desktop shortcuts
Desktop shortcuts can be created for a VM, the shortcuts are saved in~/.local/share/applications. Here is an example of how to create a
shortcut.
quickemu --vm ubuntu-22.04-desktop.conf --shortcutReferences
Useful reference that assisted the development of Quickemu.
- General
- macOS
- https://www.nicksherlock.com/2020/06/installing-macos-big-sur-on-proxmox/
- https://passthroughpo.st/mac-os-adds-early-support-for-virtio-qemu/
- https://github.com/kholia/OSX-KVM
- https://github.com/thenickdude/KVM-Opencore
- https://gist.github.com/MCJack123/943eaca762730ca4b7ae460b731b68e7
- https://github.com/acidanthera/OpenCorePkg/tree/master/Utilities/macrecovery
- https://www.kraxel.org/blog/2017/09/running-macos-as-guest-in-kvm/
- https://www.nicksherlock.com/2017/10/passthrough-of-advanced-cpu-features-for-macos-high-sierra-guests/
- http://philjordan.eu/osx-virt/
- https://github.com/Dids/clover-builder
- OpenCore Configurator
- Windows
- https://www.heiko-sieger.info/running-windows-10-on-linux-using-kvm-with-vga-passthrough/
- https://leduccc.medium.com/improving-the-performance-of-a-windows-10-guest-on-qemu-a5b3f54d9cf5
- https://frontpagelinux.com/tutorials/how-to-use-linux-kvm-to-optimize-your-windows-10-virtual-machine/
- https://turlucode.com/qemu-command-line-args/
- https://github.com/pbatard/Fido
- https://www.catapultsystems.com/blogs/create-zero-touch-windows-10-iso/
- TPM
- 9p & virtiofs
AUTHORS
Written by Martin Wimpress.
BUGS
Submit bug reports online at:
https://github.com/quickemu-project/quickemu/issues
SEE ALSO
Full sources at: https://github.com/quickemu-project/quickemu
quickemu_conf(5), quickget(1), quickgui(1)
File: docs/quickemu_conf.5.md
author: Martin Wimpress date: February 2, 2026 footer: quickemu_conf header: Quickemu Configuration Manual section: 5 title: QUICKEMU_CONF
NAME
quickemu_conf - Options and parameters in the quickemu <vm>.conf
DESCRIPTION
quickemu will create and run highly optimised desktop virtual
machines for Linux, macOS and Windows. It uses sensible defaults, but
many configuration options can be overridden in the required
configuration file, which will as a minimum specify the path to the
installation ISO and QEMU disk for the installed VM
OPTIONS
These are the options and defaults for the <vm>.conf file
# Lowercase variables are used in the VM config file only
boot="efi"
cpu_cores=""
disk_img=""
disk_size=""
display=""
extra_args=""
fixed_iso=""
floppy=""
guest_os="linux"
img=""
iso=""
macaddr=""
macos_release=""
network=""
port_forwards=()
preallocation="off"
ram=""
secureboot="off"
tpm="off"
usb_devices=()
viewer="spicy"
ssh_port=""
spice_port=""
public_dir=""
monitor="socket"
monitor_telnet_port="4440"
monitor_telnet_host="localhost"
monitor_cmd=""
serial="socket"
serial_telnet_port="6660"
serial_telnet_host="localhost"
# options: ehci(USB2.0), xhci(USB3.0)
usb_controller="ehci"
# options: ps2, usb, virtio
keyboard="usb"
keyboard_layout="en-us"
# options: ps2, usb, tablet, virtio
mouse="tablet"EXAMPLES
guest_os="linux"
disk_img="debian-bullseye/disk.qcow2"
iso="debian-bullseye/firmware-11.0.0-amd64-DVD-1.iso"The default macOS configuration looks like this:
guest_os="macos"
img="macos-catalina/RecoveryImage.img"
disk_img="macos-catalina/disk.qcow2"
macos_release="catalina"guest_os="macos"instructs Quickemu to optimise for macOS.macos_release="catalina"instructs Quickemu to optimise for a
particular macOS release.- For example VirtIO Network and Memory Ballooning are available in
Big Sur and newer, but not previous releases. - And VirtIO Block Media (disks) are supported/stable in Catalina and
newer.
- For example VirtIO Network and Memory Ballooning are available in
The default Windows 11 configuration looks like this:
guest_os="windows"
disk_img="windows-11/disk.qcow2"
iso="windows-11/Win11_EnglishInternational_x64.iso"
fixed_iso="windows-11/virtio-win.iso"
tpm="on"
secureboot="on"guest_os="windows"instructsquickemuto optimise for Windows.fixed_iso=specifies the ISO image that provides VirtIO drivers.tpm="on"instructsquickemuto create a software emulated TPM
device usingswtpm.
BIOS and EFI
Since Quickemu 2.1.0 efi is the default boot option. If you want to
override this behaviour then add the following line to you VM
configuration to enable legacy BIOS.
boot="legacy"- Enable Legacy BIOS boot
Tuning CPU cores, RAM & disks
By default, Quickemu will calculate the number of CPUs cores and RAM to
allocate to a VM based on the specifications of your host computer. You
can override this default behaviour and tune the VM configuration to
your liking.
Add additional lines to your virtual machine configuration:
cpu_cores="4"- Specify the number of CPU cores allocated to the VMram="4G"- Specify the amount of RAM to allocate to the VMdisk_size="16G"- Specify the size of the virtual disk allocated to
the VM
Disk preallocation
Preallocation mode (allowed values: off (default), metadata,falloc, full). An image with preallocated metadata is initially
larger but can improve performance when the image needs to grow.
Specify what disk preallocation should be used, if any, when creating
the system disk image by adding a line like this to your VM
configuration.
preallocation="metadata"
CD-ROM disks
If you want to expose an ISO image from the host to guest add the
following line to the VM configuration:
fixed_iso="/path/to/image.iso"
Floppy disks
If you're like Alan Pope you'll probably want to
mount a floppy disk image in the guest. To do so add the following line
to the VM configuration:
floppy="/path/to/floppy.img"
File Sharing
All File Sharing options will only expose ~/Public (or localised
variations) for the current user to the guest VMs.
Samba ๐ง ๐ ๐ช
If smbd is available on the host, Quickemu will automatically enable
the built-in QEMU support for exposing a Samba share from the host to
the guest.
You can install the minimal Samba components on Ubuntu using:
sudo apt install --no-install-recommends sambaIf everything is set up correctly, the smbd address will be printed
when the virtual machine is started. For example:
- smbd: On guest: smb://10.0.2.4/qemuIf using a Windows guest, right-click on "This PC", click "Add a network
location", and paste this address, removing smb: and replacing forward
slashes with backslashes (in this example \\10.0.2.4\qemu).
SPICE WebDAV ๐ง ๐ช
- TBD
VirtIO-9P ๐ง ๐
- TBD
Networking
Port forwarding
Add an additional line to your virtual machine configuration. For
example:
port_forwards=("8123:8123" "8888:80")
In the example above:
- Port 8123 on the host is forwarded to port 8123 on the guest.
- Port 8888 on the host is forwarded to port 80 on the guest.
Disable networking
To completely disable all network interfaces in a guest VM add this
additional line to your virtual machine configuration:
network="none"
Restricted networking
You can isolate the guest from the host (and broader network) using the
restrict option, which will restrict networking to just the guest and
any virtual devices.
This can be used to prevent software running inside the guest from
phoning home while still providing a network inside the guest. Add this
additional line to your virtual machine configuration:
network="restrict"
Bridged networking
Connect your virtual machine to a preconfigured network bridge. Add an
additional line to your virtual machine configuration:
network="br0"
If you want to have a persistent MAC address for your bridged network
interface in the guest VM you can add macaddr to the virtual machine
configuration. QEMU requires that the MAC address is in the range:
52:54:00:AB:00:00 - 52:54:00:AB:FF:FF
So you can generate your own MAC addresses with:
macaddr="52:54:00:AB:51:AE"
USB redirection
Quickemu supports USB redirection via SPICE pass-through and host
pass-through. Quickemu supports USB redirection via SPICE pass-through
and host pass-through.
NOTE! When a USB device is redirected from the host, it will not be
usable by host operating system until the guest redirection is stopped.
Therefore, do not redirect the input devices, such as the keyboard and
mouse, as it will be difficult (or impossible) to revert the situation.
SPICE redirection (recommended)
Using SPICE for USB pass-through is easiest as it doesn't require any
elevated permission:
Both spicy from
spice-gtk (Input ->
Select USB Devices for redirection) and remote-viewer from
virt-viewer (File -> USB
device selection) support this feature.
- Start Quickemu with
--display spiceand then - Select
Input->Select USB Device for redirectionfrom the menu
to choose which device(s) you want to attach to the guest. - **
spicy(default)- **Select
Input->Select USB Device for redirectionfrom the
menu to choose which device(s) you want to attach to the guest.
- **Select
- **
remote-viewer- **Select
File->USB device selectionfrom the menu to choose
which device(s) you want to attach to the guest.
- **Select
To ensure that this functionality works as expected, make sure that you
have installed the necessary SPICE Guest Tools on the virtual machine.
Enabling SPICE redirection on NixOS
On NixOS, if you encounter this error:
Error setting facl: Operation not permittedTry setting the following
option:
virtualisation.spiceUSBRedirection.enable = true;Host redirection (**NOT Recommended**)
USB host redirection is not recommended, it is provided purely for
backwards compatibility to older versions of Quickemu. Using SPICE is
preferred, see above.
Add an additional line to your virtual machine configuration. For
example:
usb_devices=("046d:082d" "046d:085e")
In the example above:
- The USB device with vendor_id 046d and product_id 082d will be exposed
to the guest. - The USB device with vendor_id 046d and product_id 085e will be exposed
to the guest.
If the USB devices are not writable, quickemu will display the
appropriate commands to modify the USB device(s) access permissions,
like this:
- USB: Host pass-through requested:
- Sennheiser Communications EPOS GTW 270 on bus 001 device 005 needs permission changes:
sudo chown -v root:user /dev/bus/usb/001/005
ERROR! USB permission changes are required ๐TPM
Since Quickemu 2.2.0 a software emulated TPM device can be added to
guest virtual machines. Just add tpm="on" to your VM configuration.quickget will automatically add this line to Windows 11 virtual
machines.
AUTHORS
Written by Martin Wimpress.
BUGS
Submit bug reports online at:
https://github.com/quickemu-project/quickemu/issues
SEE ALSO
Full sources at: https://github.com/quickemu-project/quickemu
quickget(1), quickemu(1), quickgui(1)
File: docs/quickget.1.md
author: Martin Wimpress date: February 2, 2026 footer: quickget header: Quickget User Manual section: 1 title: QUICKGET
NAME
quickget - download and prepare materials for building a quickemu VM
SYNOPSIS
quickget [os] [release] [edition] | [OPTION]*
DESCRIPTION
quickget will download the requisite materials and prepare a
configuration for quickemu to use to build and run
OPTIONS
[OS] [Release] [Edition]
: specify the OS and release (and optional edition) if insufficient
input is provided a list of missing options will be reported and the
script will exit. Editions may not apply and will be defaulted if
not provided.
--download
: Download image; no VM configuration
--create-config
: Create VM config for a OS image
--open-homepage
: Open homepage for the OS
--show [os]
: Show OS information
--url [os] [release] [edition]
: Show image URL(s)
--check [os] [release] [edition]
: Check image URL(s)
--list
: List all supported systems
--list-csv
: List everything in csv format
--list-json
: List everything in json format
--version
: Show version
--help
: Show this help message
NOTES
Creating Linux guests ๐ง
Ubuntu
quickget will automatically download an Ubuntu release and create the
virtual machine configuration.
quickget ubuntu 22.04
quickemu --vm ubuntu-22.04.conf- Complete the installation as normal.
- Post-install:
- Install the SPICE agent (
spice-vdagent) in the guest to enable
copy/paste and USB redirectionsudo apt install spice-vdagent
- Install the SPICE WebDAV agent (
spice-webdavd) in the guest to
enable file sharing.sudo apt install spice-webdavd
- Install the SPICE agent (
Ubuntu daily-live images
quickget can also download/refresh daily-live images via zsync for
Ubuntu developers and testers.
quickget ubuntu daily-live
quickemu --vm ubuntu-daily-live.confYou can run quickget ubuntu daily-live to refresh your daily
development image as often as you like, it will even automatically
switch to a new series.
Ubuntu Flavours
All the official Ubuntu flavours are supported, just replace ubuntu
with your preferred flavour.
The project
wiki
may have further information.
edubuntu(Edubuntu)kubuntu(Kubuntu)lubuntu(Lubuntu)ubuntu-budgie(Ubuntu Budgie)ubuntucinnamon(Ubuntu Cinnamon)ubuntukylin(Ubuntu Kylin)ubuntu-mate(Ubuntu MATE)ubuntu-server(Ubuntu Server)ubuntustudio(Ubuntu Studio)ubuntu(Ubuntu)ubuntu-unity(Ubuntu Unity)xubuntu(Xubuntu)
You can also use quickget with advanced options :
--arch <arch> : Set architecture (arm64, aarch64, amd64, x86_64)
--download <os> <release> [edition] : Download image; no VM configuration
--create-config <os> [path/url] [flags] : Create VM config for an OS image
--open-homepage <os> : Open homepage for the OS
--show [os] : Show OS information
--version : Show version
--help : Show this help message
------------------------------------ Flags -------------------------------------
--create-config:
--disable-unattended : Force quickget not to set up an unattended installation
-------------------------- For testing & development ---------------------------
--url [os] [release] [edition] : Show image URL(s)
--check [os] [release] [edition] : Check image URL(s)
--check-all-arch [os] [release] [edition] : Check downloads for all architectures (amd64 and arm64)
--list : List all supported systems
--list-csv : List everything in csv format
--list-json : List everything in json formatHere are some typical uses
# show an OS ISO download URL for {os} {release} [edition]
quickget --url fedora 38 Silverblue
# test if an OS ISO is available for {os} {release} [edition]
quickget --check nixos unstable plasma5
# open an OS distribution homepage in a browser
quickget --open-homepage ubuntu-mate
# Only download image file into current directory, without creating VM
quickget --download elementary 7.1The --url, --check, and --download options are fully functional
for all operating systems, including Windows and macOS.
Further information is available from the project
wiki
Other Operating Systems
quickget also supports:
alma(AlmaLinux)alpine(Alpine Linux)android(Android x86)antix(Antix)archcraft(Archcraft)archlinux(Arch Linux)artixlinux(Artix Linux)azurelinux(Azure Linux)batocera(Batocera)bazzite(Bazzite)biglinux(BigLinux)blendos(BlendOS)bodhi(Bodhi)bunsenlabs(BunsenLabs)cachyos(CachyOS)centos-stream(CentOS Stream)chimeralinux(Chimera Linux)crunchbang++(Crunchbangplusplus)debian(Debian)deepin(Deepin)devuan(Devuan)dragonflybsd(DragonFlyBSD)easyos(EasyOS)elementary(elementary OS)endeavouros(EndeavourOS)endless(Endless OS)fedora(Fedora)freebsd(FreeBSD)freedos(FreeDOS)garuda(Garuda Linux)gentoo(Gentoo)ghostbsd(GhostBSD)gnomeos(GNOME OS)guix(Guix)haiku(Haiku)kali(Kali)kdeneon(KDE Neon)kolibrios(KolibriOS)linuxlite(Linux Lite)linuxmint(Linux Mint)lmde(Linux Mint Debian Edition)maboxlinux(Mabox Linux)mageia(Mageia)manjaro(Manjaro)mxlinux(MX Linux)netboot(netboot.xyz)netbsd(NetBSD)nitrux(Nitrux)nixos(NixOS)nwg-shell(nwg-shell)openbsd(OpenBSD)openindiana(OpenIndiana)opensuse(openSUSE)oraclelinux(Oracle Linux)parrotsec(Parrot Security)pclinuxos(PCLinuxOS)peppermint(PeppermintOS)popos(Pop!_OS)porteus(Porteus)primtux(PrimTux)proxmox-ve(Proxmox VE)pureos(PureOS)reactos(ReactOS)rebornos(RebornOS)rockylinux(Rocky Linux)siduction(Siduction)slackware(Slackware)slax(Slax)slint(Slint)slitaz(SliTaz)solus(Solus)sparkylinux(SparkyLinux)spirallinux(SpiralLinux)tails(Tails)tinycore(Tiny Core Linux)trisquel(Trisquel)tuxedo-os(Tuxedo OS)vanillaos(Vanilla OS)void(Void Linux)zorin(Zorin OS)
[Custom Linux guests](https://github.com/quickemu-project/quickemu/wiki/02-Create-Linux-virtual-machines#manually-create-linux-guests)
Or you can download a Linux image and manually create a VM
configuration.
- Download a .iso image of a Linux distribution
- Create a VM configuration file; for example
debian-bullseye.conf
guest_os="linux"
disk_img="debian-bullseye/disk.qcow2"
iso="debian-bullseye/firmware-11.0.0-amd64-DVD-1.iso"- Use
quickemuto start the virtual machine:
quickemu --vm debian-bullseye.conf- Complete the installation as normal.
- Post-install:
- Install the SPICE agent (
spice-vdagent) in the guest to enable
copy/paste and USB redirection. - Install the SPICE WebDAV agent (
spice-webdavd) in the guest to
enable file sharing.
- Install the SPICE agent (
Supporting old Linux distros
If you want to run an old Linux , from 2016 or earlier, change theguest_os to linux_old. This will enable the vmware-svga graphics
driver which is better supported on older distros.
[Creating macOS Guests](https://github.com/quickemu-project/quickemu/wiki/03-Create-macOS-virtual-machines#automatically-create-macos-guests) ๐
Installing macOS in a VM can be a bit finicky, if you encounter
problems, check the
Discussions
for solutions or ask for help there ๐
quickget automatically downloads a macOS recovery image and creates a
virtual machine configuration.
Note: Some VPN users may need to turn off their
VPN
in order to download a recovery image. Some other users may find using
a
VPN
necessary in order to download a recovery image.
quickget macos big-sur
quickemu --vm macos-big-sur.confmacOS mojave, catalina, big-sur, monterey, ventura andsonoma are supported.
- Use cursor keys and enter key to select the macOS Base System
- From macOS Utilities
- Click Disk Utility and Continue
- Select
QEMU HARDDISK Media(~103.08GB) from the list (on Big Sur
and above useApple Inc. VirtIO Block Device) and click
Erase. - Enter a
Name:for the disk - If you are installing macOS Mojave or later (Catalina, Big Sur,
Monterey, Ventura and Sonoma), choose any of the APFS options as
the filesystem. MacOS Extended may not work.
- Select
- Click Erase.
- Click Done.
- Close Disk Utility
- Click Disk Utility and Continue
- From macOS Utilities
- Click Reinstall macOS and Continue
- Complete the installation as you normally would.
- On the first reboot use cursor keys and enter key to select macOS
Installer - On the subsequent reboots use cursor keys and enter key to select
the disk you named
- On the first reboot use cursor keys and enter key to select macOS
- Once you have finished installing macOS you will be presented with an
the out-of-the-box first-start wizard to configure various options and
set up your username and password - OPTIONAL: After you have concluded the out-of-the-box wizard, you may
want to enable the TRIM feature that the computer industry created for
SSD disks. This feature in our macOS installation will allow QuickEmu
to compact (shrink) your macOS disk image whenever you delete files
inside the Virtual Machine. Without this step your macOS disk image
will only ever get larger and will not shrink even when you delete
lots of data inside macOS.- To enable TRIM, open the Terminal application and type the following
command followed by pressing enter to tell macos to use
the TRIM command on the hard disk when files are deleted:
- To enable TRIM, open the Terminal application and type the following
sudo trimforce enableYou will be prompted to enter your account's password to gain the
privilege needed. Once you've entered your password and pressed
enter the command will request confirmation in the form of
two questions that require you to type y (for a "yes"
response) followed by enter to confirm.
If you press enter without first typing y the
system will consider that a negative response as though you said "no":
IMPORTANT NOTICE: This tool force-enables TRIM for all relevant attached devices, even though such devices may not have been validated for data integrity while using TRIM. Use of this tool to enable TRIM may result in unintended data loss or data corruption. It should not be used in a commercial operating environment or with important data. Before using this tool, you should back up all of your data and regularly back up data while TRIM is enabled. This tool is provided on an "as is" basis. APPLE MAKES NO WARRANTIES, EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION THE IMPLIED WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE, REGARDING THIS TOOL OR ITS USE ALONE OR IN COMBINATION WITH YOUR DEVICES, SYSTEMS, OR SERVICES. BY USING THIS TOOL TO ENABLE TRIM, YOU AGREE THAT, TO THE EXTENT PERMITTED BY APPLICABLE LAW, USE OF THE TOOL IS AT YOUR SOLE RISK AND THAT THE ENTIRE RISK AS TO SATISFACTORY QUALITY, PERFORMANCE, ACCURACY AND EFFORT IS WITH YOU.
Are you sure you with to proceed (y/N)?And a second confirmation once you've confirmed the previous one:
Your system will immediately reboot when this is complete.
Is this OK (y/N)?As the last message states, your system will automatically reboot as
soon as the command completes.
The default macOS configuration looks like this:
guest_os="macos"
img="macos-big-sur/RecoveryImage.img"
disk_img="macos-big-sur/disk.qcow2"
macos_release="big-sur"guest_os="macos"instructs Quickemu to optimise for macOS.macos_release="big-sur"instructs Quickemu to optimise for a
particular macOS release.- For example VirtIO Network and Memory Ballooning are available in
Big Sur and newer, but not previous releases. - And VirtIO Block Media (disks) are supported/stable in Catalina and
newer.
- For example VirtIO Network and Memory Ballooning are available in
macOS compatibility
There are some considerations when running macOS via Quickemu.
- Supported macOS releases:
- Mojave
- Catalina
- Big Sur
- Monterey
- Ventura
- Sonoma
quickemuwill automatically download the required
OpenCore bootloader and
OVMF firmware from OSX-KVM.- Optimised by default, but no GPU acceleration is available.
- Host CPU vendor is detected and guest CPU is optimised accordingly.
- VirtIO Block
Media is
used for the system disk where supported. - VirtIO
usb-tabletis used for
the mouse. - VirtIO Network (
virtio-net) is supported and enabled on macOS Big
Sur and newer, but earlier releases usevmxnet3. - VirtIO Memory Ballooning is supported and enabled on macOS Big Sur
and newer but disabled for other support macOS releases.
- USB host and SPICE pass-through is:
- UHCI (USB 2.0) on macOS Catalina and earlier.
- XHCI (USB 3.0) on macOS Big Sur and newer.
- Display resolution can be changed via
quickemuusing--widthand--heightcommand line arguments. - Full Duplex audio requires VoodooHDA
OC or pass-through a USB
audio-device to the macOS guest VM.- NOTE! Gatekeeper and
System Integrity Protection
(SIP)
need to be disabled to install VoodooHDA OC
- NOTE! Gatekeeper and
- File sharing between guest and host is available via
virtio-9p and SPICE
webdavd. - Copy/paste via SPICE agent is not available on macOS.
macOS App Store
If you see "Your device or computer could not be verified" when you
try to login to the App Store, make sure that your wired ethernet device
is en0. Use ifconfig in a terminal to verify this.
If the wired ethernet device is not en0, then then go to System
Preferences -> Network, delete all the network devices and apply the
changes. Next, open a terminal and run the following:
sudo rm /Library/Preferences/SystemConfiguration/NetworkInterfaces.plistNow reboot, and the App Store should work.
There may be further advice and information about macOS guests in the
project
wiki.
[Creating Windows guests](https://github.com/quickemu-project/quickemu/wiki/04-Create-Windows-virtual-machines) ๐ช
quickget can download Windows
10 and
Windows 11
automatically and create an optimised virtual machine configuration.
This configuration also includes the VirtIO drivers for
Windows.
Windows 8.1 is also supported but doesn't feature any automated
installation or driver optimisation.
quickget can also download Windows 10
LTSC
and Windows Server
2012-r2,
2016,
2019,
and
2022.
No automated installation is supported for these releases.
quickget windows 11
quickemu --vm windows-11.conf- Complete the installation as you normally would.
- All relevant drivers and services should be installed automatically.
- A local administrator user account is automatically created, with
these credentials:- Username:
Quickemu - Password:
quickemu
- Username:
Further information is available from the project
wiki
AUTHORS
Written by Martin Wimpress.
BUGS
Submit bug reports online at:
https://github.com/quickemu-project/quickemu/issues
SEE ALSO
Full sources at: https://github.com/quickemu-project/quickemu
quickemu(1), quickemu_conf(5), quickgui(1)